package Bundle::Locale::CLDR::Southernafrica;

use version;

our $VERSION = version->declare('v0.46.0');

=head1 NAME

Bundle::Locale::CLDR::Southernafrica

=head1 CONTENTS

Locale::CLDR::Locales::Af 0.46.0

Locale::CLDR::Locales::Nr 0.46.0

Locale::CLDR::Locales::Ss 0.46.0

Locale::CLDR::Locales::St 0.46.0

Locale::CLDR::Locales::Tn 0.46.0

Locale::CLDR::Locales::Ts 0.46.0

Locale::CLDR::Locales::Ve 0.46.0

Locale::CLDR::Locales::Xh 0.46.0

Locale::CLDR::Locales::Zu 0.46.0

Locale::CLDR::Locales::Naq 0.46.0

Locale::CLDR::Locales::Nso 0.46.0

Locale::CLDR::Locales::Af::Latn 0.46.0

Locale::CLDR::Locales::Nr::Latn 0.46.0

Locale::CLDR::Locales::Ss::Latn 0.46.0

Locale::CLDR::Locales::St::Latn 0.46.0

Locale::CLDR::Locales::Tn::Latn 0.46.0

Locale::CLDR::Locales::Ts::Latn 0.46.0

Locale::CLDR::Locales::Ve::Latn 0.46.0

Locale::CLDR::Locales::Xh::Latn 0.46.0

Locale::CLDR::Locales::Zu::Latn 0.46.0

Locale::CLDR::Locales::Naq::Latn 0.46.0

Locale::CLDR::Locales::Nso::Latn 0.46.0

Locale::CLDR::Locales::Af::Latn::Na 0.46.0

Locale::CLDR::Locales::Af::Latn::Za 0.46.0

Locale::CLDR::Locales::En::Latn::Bw 0.46.0

Locale::CLDR::Locales::En::Latn::Ls 0.46.0

Locale::CLDR::Locales::En::Latn::Na 0.46.0

Locale::CLDR::Locales::En::Latn::Sz 0.46.0

Locale::CLDR::Locales::En::Latn::Za 0.46.0

Locale::CLDR::Locales::Nr::Latn::Za 0.46.0

Locale::CLDR::Locales::Ss::Latn::Sz 0.46.0

Locale::CLDR::Locales::Ss::Latn::Za 0.46.0

Locale::CLDR::Locales::St::Latn::Ls 0.46.0

Locale::CLDR::Locales::St::Latn::Za 0.46.0

Locale::CLDR::Locales::Tn::Latn::Bw 0.46.0

Locale::CLDR::Locales::Tn::Latn::Za 0.46.0

Locale::CLDR::Locales::Ts::Latn::Za 0.46.0

Locale::CLDR::Locales::Ve::Latn::Za 0.46.0

Locale::CLDR::Locales::Xh::Latn::Za 0.46.0

Locale::CLDR::Locales::Zu::Latn::Za 0.46.0

Locale::CLDR::Locales::En::Latn::001 0.46.0

Locale::CLDR::Locales::Naq::Latn::Na 0.46.0

Locale::CLDR::Locales::Nso::Latn::Za 0.46.0


=cut

1;

